==> VVAS-DataCenter-core-6.0.0-sources.jar: com/viontech/keliu/processor/xml/VionXmlMessageProcessor.java <==
package com.viontech.keliu.processor.xml;

import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;

import com.viontech.keliu.model.Body;
import com.viontech.keliu.model.Content;
import com.viontech.keliu.processor.VionMessageProcessor;

import io.netty.buffer.ByteBuf;

public abstract class VionXmlMessageProcessor extends VionMessageProcessor{
	private static final String ELEMENT_NAME_ROOT = "root";
	private static final String ELEMENT_NAME_VENDOR = "vendor";
	private static final String ELEMENT_NAME_CATEGORY = "category";
	private static final String ELEMENT_NAME_COMMAND = "command";
	private static final String ELEMENT_NAME_MESSAGEID = "messageid";
	private static final String ELEMENT_NAME_SOURCE = "source";
	private static final String ELEMENT_NAME_DESTINATION = "destination";
	private static final String ELEMENT_NAME_CONTENT = "content";
	

	protected static final String CONTENT_PROPERTY_STASTUS = "status";
	protected static final String CONTENT_PROPERTY_ERRORDESC = "ErrorDesc";

	public VionXmlMessageProcessor() {
		super();
	}

	public Body parseBody(ByteBuf byteBuf){
        try {
        	Body body = new  Body();
        	long size = byteBuf.getUnsignedInt(0);
        	String xmlStr = byteBuf.readCharSequence((int)(size-16), charset).toString().trim();
        	//System.out.println(xmlStr);
        	Document doc = DocumentHelper.parseText(xmlStr); // 将字符串转为XML
            Element rootElt = doc.getRootElement(); // 获取根节点
            try {
            	
				Element vendorElement = rootElt.element(ELEMENT_NAME_VENDOR);
				if(vendorElement != null){
					String vendor = vendorElement.getTextTrim();
					body.setVendor(vendor);
				}
				
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element categoryElement = rootElt.element(ELEMENT_NAME_CATEGORY);
				String category = categoryElement.getTextTrim();
				body.setCategory(category);
			} catch (Exception e) {
				e.printStackTrace();
			}
            try {
				Element commandElement = rootElt.element(ELEMENT_NAME_COMMAND);
				String command = commandElement.getTextTrim();
				body.setCommand(command);
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element messageIdElement = rootElt.element(ELEMENT_NAME_MESSAGEID);
				String messageId = messageIdElement.getTextTrim();
				body.setMessageId(messageId);
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element sourceElement = rootElt.element(ELEMENT_NAME_SOURCE);
				if(sourceElement != null){
					String source = sourceElement.getTextTrim();
					body.setSource(source);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element destinationElement = rootElt.element(ELEMENT_NAME_DESTINATION);
				if(destinationElement != null){
					String destination = destinationElement.getTextTrim();
					body.setDestination(destination);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
            try {
				Element contentElement = rootElt.element(ELEMENT_NAME_CONTENT);
				Content content = parseContent(contentElement);
				body.setContent(content);
				
			} catch (Exception e) {
				e.printStackTrace();
			}
            return body;
        }catch(Exception e){
        	e.printStackTrace();
        }
		
		return null;
		
	}
	
	public abstract Content parseContent(Element contentElement);
	
	
	
	
	@Override
	public boolean isValid(ByteBuf byteBuf) {
		long size = byteBuf.getUnsignedInt(0);
		long version = byteBuf.getUnsignedInt(8);
		long type = byteBuf.getUnsignedInt(12);
		if(type != MESSAGE_TYPE_XML){
			return false;
		}
		Document doc = null;
        try {
        
        	String xml = byteBuf.getCharSequence(16, (int)(size-16), charset).toString().trim();
            doc = DocumentHelper.parseText(xml); // 将字符串转为XML
            Element rootElt = doc.getRootElement(); // 获取根节点
            Element commandElement = rootElt.element(ELEMENT_NAME_COMMAND);
            String command = commandElement.getTextTrim();
			//  System.out.println(command);
            if(command.equals(supportCommand()) && version == supportVersion()){
				return true;
			}
        }catch(Exception e){
        	e.printStackTrace();
        }
        return false;
	}
	
	protected abstract boolean buildByteBufContent(Content content,Element contentElt);
	@Override
	protected boolean buildByteBufBody(Body body, ByteBuf byteBuf) {
		try {
			Document document = DocumentHelper.createDocument();
			document.setXMLEncoding("GBK");
			Element root = document.addElement(ELEMENT_NAME_ROOT);
			Element vendor = root.addElement(ELEMENT_NAME_VENDOR);
			vendor.setText(body.getVendor());
			Element category = root.addElement(ELEMENT_NAME_CATEGORY);
			category.setText(getResponseCategory());
			Element command = root.addElement(ELEMENT_NAME_COMMAND);
			command.setText(body.getCommand());
			Element messageId = root.addElement(ELEMENT_NAME_MESSAGEID);
			messageId.setText(body.getMessageId());
			Element content = root.addElement(ELEMENT_NAME_CONTENT);
			boolean success = buildByteBufContent(body.getContent(), content);
			if(!success) return success;
			String xmlStr = document.asXML();
			byteBuf.writeBytes(xmlStr.getBytes(charset));
			byteBuf.writeByte(0X00);
			return true;
		} catch (Exception e) {
			e.printStackTrace();
		}
        
		return false;
	}
	
}

==> VVAS-DataCenter-core-6.1.4-sources.jar: com/viontech/keliu/processor/xml/VionXmlMessageProcessor.java <==
package com.viontech.keliu.processor.xml;

import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;

import com.viontech.keliu.content.Body;
import com.viontech.keliu.content.Content;
import com.viontech.keliu.processor.VionMessageProcessor;

import io.netty.buffer.ByteBuf;

public abstract class VionXmlMessageProcessor extends VionMessageProcessor{

	private static final String ELEMENT_NAME_VENDOR = "vendor";
	private static final String ELEMENT_NAME_CATEGORY = "category";

	private static final String ELEMENT_NAME_MESSAGEID = "messageid";
	private static final String ELEMENT_NAME_SOURCE = "source";
	private static final String ELEMENT_NAME_DESTINATION = "destination";
	private static final String ELEMENT_NAME_CONTENT = "content";
	

	protected static final String CONTENT_PROPERTY_STASTUS = "status";
	protected static final String CONTENT_PROPERTY_ERRORDESC = "ErrorDesc";

	public VionXmlMessageProcessor() {
		super();
	}

	public Body parseBody(ByteBuf byteBuf){
        try {
        	Body body = new  Body();
        	long size = byteBuf.getUnsignedInt(0);
        	String xmlStr = byteBuf.readCharSequence((int)(size-16), charset).toString().trim();
        	System.out.println(xmlStr);
        	Document doc = DocumentHelper.parseText(xmlStr); // 将字符串转为XML
            Element rootElt = doc.getRootElement(); // 获取根节点
            try {
            	
				Element vendorElement = rootElt.element(ELEMENT_NAME_VENDOR);
				if(vendorElement != null){
					String vendor = vendorElement.getTextTrim();
					body.setVendor(vendor);
				}
				
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element categoryElement = rootElt.element(ELEMENT_NAME_CATEGORY);
				String category = categoryElement.getTextTrim();
				body.setCategory(category);
			} catch (Exception e) {
				e.printStackTrace();
			}
            try {
				Element commandElement = rootElt.element(ELEMENT_NAME_COMMAND);
				String command = commandElement.getTextTrim();
				body.setCommand(command);
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element messageIdElement = rootElt.element(ELEMENT_NAME_MESSAGEID);
				String messageId = messageIdElement.getTextTrim();
				body.setMessageId(messageId);
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element sourceElement = rootElt.element(ELEMENT_NAME_SOURCE);
				if(sourceElement != null){
					String source = sourceElement.getTextTrim();
					body.setSource(source);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
            
            try {
				Element destinationElement = rootElt.element(ELEMENT_NAME_DESTINATION);
				if(destinationElement != null){
					String destination = destinationElement.getTextTrim();
					body.setDestination(destination);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
            try {
				Element contentElement = rootElt.element(ELEMENT_NAME_CONTENT);
				Content content = parseContent(contentElement);
				body.setContent(content);
				
			} catch (Exception e) {
				e.printStackTrace();
			}
            return body;
        }catch(Exception e){
        	e.printStackTrace();
        }
		
		return null;
		
	}
	
	public abstract Content parseContent(Element contentElement);
	
	
	
	
	@Override
	public boolean isValid(ByteBuf byteBuf) {
		long size = byteBuf.getUnsignedInt(0);
		long version = byteBuf.getUnsignedInt(8);
		long type = byteBuf.getUnsignedInt(12);
		if(type != MESSAGE_TYPE_XML){
			return false;
		}
		Document doc = null;
        try {
        
        	String xml = byteBuf.getCharSequence(16, (int)(size-16), charset).toString().trim();
            doc = DocumentHelper.parseText(xml); // 将字符串转为XML
            Element rootElt = doc.getRootElement(); // 获取根节点
            Element commandElement = rootElt.element(ELEMENT_NAME_COMMAND);
            String command = commandElement.getTextTrim();
			//  System.out.println(command);
            if(command.equals(supportCommand()) && version == supportVersion()){
				return true;
			}
        }catch(Exception e){
        	e.printStackTrace();
        }
        return false;
	}
	
	protected abstract boolean buildByteBufContent(Content content,Element contentElt);
	@Override
	protected boolean buildByteBufBody(Body body, ByteBuf byteBuf) {
		try {
			Document document = DocumentHelper.createDocument();
			document.setXMLEncoding("GBK");
			Element root = document.addElement(ELEMENT_NAME_ROOT);
			Element vendor = root.addElement(ELEMENT_NAME_VENDOR);
			vendor.setText(body.getVendor());
			Element category = root.addElement(ELEMENT_NAME_CATEGORY);
			category.setText(getResponseCategory());
			Element command = root.addElement(ELEMENT_NAME_COMMAND);
			command.setText(body.getCommand());
			Element messageId = root.addElement(ELEMENT_NAME_MESSAGEID);
			messageId.setText(body.getMessageId());
			Element content = root.addElement(ELEMENT_NAME_CONTENT);
			boolean success = buildByteBufContent(body.getContent(), content);
			if(!success) return success;
			String xmlStr = document.asXML();
			System.out.println(xmlStr);
			byteBuf.writeBytes(xmlStr.getBytes(charset));
			byteBuf.writeByte(0X00);
			return true;
		} catch (Exception e) {
			e.printStackTrace();
		}
        
		return false;
	}
	@Override
	public long supportType() {
		return MESSAGE_TYPE_XML;
	}
	
}
